.. todoist-python documentation master file, created by
   sphinx-quickstart on Tue Jul 22 11:37:51 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Overview
========

The official Todoist Python API library.

Modules
=======

.. toctree::
   :maxdepth: 2

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

